[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- weblogolib.color.Color: Color specifications using CSS2 (Cascading Style Sheet) syntax.
- object: The most base type
  - weblogolib.colorscheme.ColorGroup: Associate a group of symbols with a color
  - weblogolib.colorscheme.ColorScheme: A coloring of an alphabet.
  - weblogolib.logomath.Dirichlet: The Dirichlet probability distribution.
  - weblogolib._cgi.Field: A representation of an HTML form field.
  - weblogolib.logomath.Gamma: The gamma probability distribution.
  - weblogolib.GhostscriptAPI: Interface to the command line program Ghostscript ('gs')
  - weblogolib.LogoData: The data needed to generate a sequence logo.
  - weblogolib.LogoOptions: A container for all logo formatting options.